<?php

/**
 * Create theme_colors palettes.
 */
function _create_palettes() {
  $storage = \Drupal::entityTypeManager()->getStorage('theme_colors');
  $palettes = _get_color_palettes();

  foreach ($palettes as $palette) {
    $new_palette = [
      'type' => 'theme_colors', 
      'label' => $palette['title']
    ];

    foreach ($palette['colors'] as $name => $color) {
      $new_palette['field_bt_' . $name] = $color;
    }
    $entity = $storage->create($new_palette);
    $entity->save();
  }
}

/**
 * Return a list of predefined color palettes.
 */
function _get_color_palettes() {
  $colors = [
    'yellow' => '#FFC107',
    'blue' => '#0D6EFD',
    'cyan' => '#0DCAF0',
    'teal' => '#20C997',
    'gray' => '#ADB5BD',
    'indigo' => '#6610F2',
    'orange' => '#FD7E14',
    'purple' => '#6F42C1',
    'red' => '#DC3545',
    'pink' => '#D63384',
    'green' => '#198754',
    'white' => '#FFFFFF'
  ];

  $grays = [
    'gray' => '#E9ECEF',
    'gray_050' => '#FFFFFF',
    'gray_100' => '#F8F9FA',
    'gray_200' => '#E9ECEF',
    'gray_300' => '##DEE2E6',
    'gray_400' => '#CED4DA',
    'gray_500' => '#FEFEFE',
    'gray_600' => '#6C757D',
    'gray_700' => '#495057',
    'gray_800' => '#343A40',
    'gray_900' => '#212529',
  ];

  $palettes = [];
  $palettes['nature'] = [
    'title' => 'Nature',
    'colors' =>   [
      'primary' => '#985E64',
      'primary_050' => '#E0CDCF',
      'primary_100' => '#D8C0C3',
      'primary_200' => '#C9A7AB',
      'primary_300' => '#B98E92',
      'primary_400' => '#A9757A',
      'primary_500' => '#985E64',
      'primary_600' => '#7E4E53',
      'primary_700' => '#653F43',
      'primary_800' => '#4C2F32',
      'primary_900' => '#291A1B',
      'secondary' => '#CB6C53',
      'secondary_050' => '#F6E4E0',
      'secondary_100' => '#F1D7D0',
      'secondary_200' => '#E7BCB1',
      'secondary_300' => '#DEA192',
      'secondary_400' => '#D48672',
      'secondary_500' => '#CB6C53',
      'secondary_600' => '#BC5439',
      'secondary_700' => '#91412C',
      'secondary_800' => '#662E1F',
      'secondary_900' => '#3B1A12',
      'accent' => '#57CE6B',
      'accent_050' => '#E5F7E8',
      'accent_100' => '#D5F3DA',
      'accent_200' => '#B6E9BE',
      'accent_300' => '#96E0A2',
      'accent_400' => '#77D786',
      'accent_500' => '#57CE6B',
      'accent_600' => '#39C350',
      'accent_700' => '#30A343',
      'accent_800' => '#237831',
      'accent_900' => '#164C1F',
      'success' => '#5B9E00',
      'info' => '#FA9E6F',
      'danger' => '#EF0066',
      'warning' => '#FFBD64',
      'light' => '#B6E9F5',
      'dark' => '#111323'
    ]
  ];

  $palettes['lagoon'] = [
    'title' => 'Lagoon',
    'colors' => [
      'primary' => '#2D46FD',
      'primary_050' => '#E3E6FF',
      'primary_100' => '#CFD5FF',
      'primary_200' => '#A6B1FE',
      'primary_300' => '#7E8DFE',
      'primary_400' => '#556AFE',
      'primary_500' => '#2D46FD',
      'primary_600' => '#0422FD',
      'primary_700' => '#021BD7',
      'primary_800' => '#0116AE',
      'primary_900' => '#011186',
      'secondary' => '#1767FD',
      'secondary_050' => '#CDDEFF',
      'secondary_100' => '#B9D1FE',
      'secondary_200' => '#90B7FE',
      'secondary_300' => '#689CFE',
      'secondary_400' => '#3F82FD',
      'secondary_500' => '#1767FD',
      'secondary_600' => '#024DDA',
      'secondary_700' => '#0139A2',
      'secondary_800' => '#01266B',
      'secondary_900' => '#001233',
      'accent' => '#EA38D9',
      'accent_050' => '#FBDEF9',
      'accent_100' => '#FACBF5',
      'accent_200' => '#F6A6EE',
      'accent_300' => '#F281E7',
      'accent_400' => '#EE5CE0',
      'accent_500' => '#EA38D9',
      'accent_600' => '#E118CD',
      'accent_700' => '#BC14AC',
      'accent_800' => '#97108A',
      'accent_900' => '#640B5C',
      'success' => '#02A460',
      'info' => '#8CA4EF',
      'danger' => '#F01E01',
      'warning' => '#E1CB02',
      'light' => '#F9D8D7',
      'dark' => '#CBE1F9'
    ]
  ];

  $palettes['pizza'] = [
    'title' => 'Pizza',
    'colors' => [
      'primary' => '#E74C3C',
      'primary_050' => '#FFEBE6',
      'primary_100' => '#FFCFC7',
      'primary_200' => '#FFA29B',
      'primary_300' => '#FF756F',
      'primary_400' => '#FF4943',
      'primary_500' => '#FF1D17',
      'primary_600' => '#E60000',
      'primary_700' => '#CC0000',
      'primary_800' => '#B30000',
      'primary_900' => '#990000',
      'secondary' => '#F1C40F',
      'secondary_050' => '#FFF8DC',
      'secondary_100' => '#FFECB3',
      'secondary_200' => '#FFE180',
      'secondary_300' => '#FFD54F',
      'secondary_400' => '#FFC21E',
      'secondary_500' => '#FFB800',
      'secondary_600' => '#E6A100',
      'secondary_700' => '#CC8E00',
      'secondary_800' => '#B37D00',
      'secondary_900' => '#996C00',
      'accent' => '#2ECC71',
      'accent_050' => '#E8F8F5',
      'accent_100' => '#D1F2EB',
      'accent_200' => '#A3E4D7',
      'accent_300' => '#76D7C4',
      'accent_400' => '#48C9B0',
      'accent_500' => '#1ABC9C',
      'accent_600' => '#17A589',
      'accent_700' => '#148F77',
      'accent_800' => '#117864',
      'accent_900' => '#0E6251',
      'success' => '#4CAF50',
      'info' => '#3498DB',
      'danger' => '#FF5722',
      'warning' => '#FF9800',
      'light' => '#FFFFFF',
      'dark' => '#000000'
    ]
  ];

  $palettes['vivid'] = [
    'title' => 'Vivid',
    'colors' => [
      'primary' => '#FF6E6E',
      'primary_050' => '#FFECEC',
      'primary_100' => '#FFCCCC',
      'primary_200' => '#FFA3A3',
      'primary_300' => '#FF7A7A',
      'primary_400' => '#FF5151',
      'primary_500' => '#FF2828',
      'primary_600' => '#FF0000',
      'primary_700' => '#E60000',
      'primary_800' => '#CC0000',
      'primary_900' => '#B30000',
      'secondary' => '#7AFF7A',
      'secondary_050' => '#E6FFE6',
      'secondary_100' => '#CCECCC',
      'secondary_200' => '#A3FFA3',
      'secondary_300' => '#7AFF7A',
      'secondary_400' => '#51FF51',
      'secondary_500' => '#28FF28',
      'secondary_600' => '#00FF00',
      'secondary_700' => '#00E600',
      'secondary_800' => '#00CC00',
      'secondary_900' => '#00B300',
      'accent' => '#6E8BFF',
      'accent_050' => '#E6EBFF',
      'accent_100' => '#CCD6FF',
      'accent_200' => '#A3BFFF',
      'accent_300' => '#7AAAFF',
      'accent_400' => '#5174FF',
      'accent_500' => '#284FFF',
      'accent_600' => '#001AFF',
      'accent_700' => '#0017E6',
      'accent_800' => '#0013CC',
      'accent_900' => '#000FB3',
      'success' => '#00FF6E',
      'info' => '#6E8BFF',
      'danger' => '#FF6E28',
      'warning' => '#FFD700',
      'light' => '#FFFFFF',
      'dark' => '#000000'
    ]
  ];

  $palettes['autoparts'] = [
    'title' => 'Autoparts',
    'colors' => [
      'primary' => '#34495E',
      'primary_050' => '#EAECEE',
      'primary_100' => '#ABB2B9',
      'primary_200' => '#808B96',
      'primary_300' => '#566573',
      'primary_400' => '#2C3E50',
      'primary_500' => '#34495E',
      'primary_600' => '#2C3E50',
      'primary_700' => '#273746',
      'primary_800' => '#212F3C',
      'primary_900' => '#1B2631',
      'secondary' => '#E67E22',
      'secondary_050' => '#FCF3CF',
      'secondary_100' => '#F9E79F',
      'secondary_200' => '#F4D03F',
      'secondary_300' => '#F5AB35',
      'secondary_400' => '#F39C12',
      'secondary_500' => '#E67E22',
      'secondary_600' => '#D35400',
      'secondary_700' => '#BA4A00',
      'secondary_800' => '#A04000',
      'secondary_900' => '#873600',
      'accent' => '#27AE60',
      'accent_050' => '#E8F6F3',
      'accent_100' => '#D1F2EB',
      'accent_200' => '#A3E4D7',
      'accent_300' => '#76D7C4',
      'accent_400' => '#48C9B0',
      'accent_500' => '#27AE60',
      'accent_600' => '#229954',
      'accent_700' => '#1E8449',
      'accent_800' => '#196F3D',
      'accent_900' => '#145A32',
      'success' => '#2ECC71',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['kids_clothing'] = [
    'title' => 'Kids Clothing',
    'colors' => [
      'primary' => '#FF6F61',
      'primary_050' => '#FFE6E3',
      'primary_100' => '#FFC7C2',
      'primary_200' => '#FFA29E',
      'primary_300' => '#FF7D7B',
      'primary_400' => '#FF5958',
      'primary_500' => '#FF3432',
      'primary_600' => '#FF1F1D',
      'primary_700' => '#E60000',
      'primary_800' => '#CC0000',
      'primary_900' => '#B30000',
      'secondary' => '#66CCFF',
      'secondary_050' => '#E5F3FF',
      'secondary_100' => '#CCE8FF',
      'secondary_200' => '#99D9FF',
      'secondary_300' => '#66CCFF',
      'secondary_400' => '#33BBFF',
      'secondary_500' => '#00AAFF',
      'secondary_600' => '#0099E6',
      'secondary_700' => '#0088CC',
      'secondary_800' => '#0077B3',
      'secondary_900' => '#006699',
      'accent' => '#FFD166',
      'accent_050' => '#FFF4CC',
      'accent_100' => '#FFEA99',
      'accent_200' => '#FFD966',
      'accent_300' => '#FFD140',
      'accent_400' => '#FFCC00',
      'accent_500' => '#FFC300',
      'accent_600' => '#E6AD00',
      'accent_700' => '#C99900',
      'accent_800' => '#AD8500',
      'accent_900' => '#916B00',
      'success' => '#00B894',
      'info' => '#0984E3',
      'danger' => '#FF4757',
      'warning' => '#FBC531',
      'light' => '#F8F9FA',
      'dark' => '#212529'
    ]
  ];

  $palettes['veterinary'] = [
    'title' => 'Veterinary',
    'colors' => [
      'primary' => '#1ABC9C',
      'primary_050' => '#E8F8F5',
      'primary_100' => '#D1F2EB',
      'primary_200' => '#A3E4D7',
      'primary_300' => '#76D7C4',
      'primary_400' => '#48C9B0',
      'primary_500' => '#1ABC9C',
      'primary_600' => '#17A589',
      'primary_700' => '#148F77',
      'primary_800' => '#117864',
      'primary_900' => '#0E6251',
      'secondary' => '#FF5722',
      'secondary_050' => '#FFEBEE',
      'secondary_100' => '#FFCDD2',
      'secondary_200' => '#EF9A9A',
      'secondary_300' => '#E57373',
      'secondary_400' => '#EF5350',
      'secondary_500' => '#FF5722',
      'secondary_600' => '#F4511E',
      'secondary_700' => '#E64A19',
      'secondary_800' => '#D84315',
      'secondary_900' => '#BF360C',
      'accent' => '#3498DB',
      'accent_050' => '#EAEFF2',
      'accent_100' => '#C5D9E8',
      'accent_200' => '#A0CCE5',
      'accent_300' => '#7FB3D5',
      'accent_400' => '#5A9AC6',
      'accent_500' => '#3498DB',
      'accent_600' => '#2B88D9',
      'accent_700' => '#2577B5',
      'accent_800' => '#1F679A',
      'accent_900' => '#195581',
      'success' => '#2ECC71',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['hair_salon'] = [
    'title' => 'Hair Salon',
    'colors' => [
      'primary' => '#FFC300',
      'primary_050' => '#FFF9E6',
      'primary_100' => '#FFF2CC',
      'primary_200' => '#FFE699',
      'primary_300' => '#FFD966',
      'primary_400' => '#FFCC33',
      'primary_500' => '#FFC300',
      'primary_600' => '#FFB300',
      'primary_700' => '#FFA300',
      'primary_800' => '#FF9400',
      'primary_900' => '#FF8500',
      'secondary' => '#8E44AD',
      'secondary_050' => '#F5EEF8',
      'secondary_100' => '#EAD7F4',
      'secondary_200' => '#D4B9E1',
      'secondary_300' => '#C39BD3',
      'secondary_400' => '#AF7AC5',
      'secondary_500' => '#8E44AD',
      'secondary_600' => '#7D3C98',
      'secondary_700' => '#6C3483',
      'secondary_800' => '#5B2C6F',
      'secondary_900' => '#4A235A',
      'accent' => '#E74C3C',
      'accent_050' => '#F9EBE7',
      'accent_100' => '#F0D9D0',
      'accent_200' => '#E6B0A5',
      'accent_300' => '#DC8179',
      'accent_400' => '#D3544F',
      'accent_500' => '#E74C3C',
      'accent_600' => '#C0392B',
      'accent_700' => '#A93226',
      'accent_800' => '#922B21',
      'accent_900' => '#7B241C',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['bakery'] = [
    'title' => 'Bakery',
    'colors' => [
      'primary' => '#FF9F1C',
      'primary_050' => '#FFF4E6',
      'primary_100' => '#FFE0B2',
      'primary_200' => '#FFD180',
      'primary_300' => '#FFBD4D',
      'primary_400' => '#FFAA1A',
      'primary_500' => '#FF9F1C',
      'primary_600' => '#FF931E',
      'primary_700' => '#FF881F',
      'primary_800' => '#FF7C21',
      'primary_900' => '#FF7122',
      'secondary' => '#8E44AD',
      'secondary_050' => '#F5EEF8',
      'secondary_100' => '#EAD7F4',
      'secondary_200' => '#D4B9E1',
      'secondary_300' => '#C39BD3',
      'secondary_400' => '#AF7AC5',
      'secondary_500' => '#8E44AD',
      'secondary_600' => '#7D3C98',
      'secondary_700' => '#6C3483',
      'secondary_800' => '#5B2C6F',
      'secondary_900' => '#4A235A',
      'accent' => '#3498DB',
      'accent_050' => '#EAEFF2',
      'accent_100' => '#C5D9E8',
      'accent_200' => '#A0CCE5',
      'accent_300' => '#7FB3D5',
      'accent_400' => '#5A9AC6',
      'accent_500' => '#3498DB',
      'accent_600' => '#2B88D9',
      'accent_700' => '#2577B5',
      'accent_800' => '#1F679A',
      'accent_900' => '#195581',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['restaurant'] = [
    'title' => 'Restaurant',
    'colors' => [
      'primary' => '#E74C3C',
      'primary_050' => '#F9EBE7',
      'primary_100' => '#F0D9D0',
      'primary_200' => '#E6B0A5',
      'primary_300' => '#DC8179',
      'primary_400' => '#D3544F',
      'primary_500' => '#E74C3C',
      'primary_600' => '#C0392B',
      'primary_700' => '#A93226',
      'primary_800' => '#922B21',
      'primary_900' => '#7B241C',
      'secondary' => '#3498DB',
      'secondary_050' => '#EAEFF2',
      'secondary_100' => '#C5D9E8',
      'secondary_200' => '#A0CCE5',
      'secondary_300' => '#7FB3D5',
      'secondary_400' => '#5A9AC6',
      'secondary_500' => '#3498DB',
      'secondary_600' => '#2B88D9',
      'secondary_700' => '#2577B5',
      'secondary_800' => '#1F679A',
      'secondary_900' => '#195581',
      'accent' => '#FFC300',
      'accent_050' => '#FFF4E6',
      'accent_100' => '#FFE0B2',
      'accent_200' => '#FFD180',
      'accent_300' => '#FFBD4D',
      'accent_400' => '#FFAA1A',
      'accent_500' => '#FF9F1C',
      'accent_600' => '#FF931E',
      'accent_700' => '#FF881F',
      'accent_800' => '#FF7C21',
      'accent_900' => '#FF7122',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['sneaker_store'] = [
    'title' => 'Sneaker Store',
    'colors' => [
      'primary' => '#3498DB',
      'primary_050' => '#EAEFF2',
      'primary_100' => '#C5D9E8',
      'primary_200' => '#A0CCE5',
      'primary_300' => '#7FB3D5',
      'primary_400' => '#5A9AC6',
      'primary_500' => '#3498DB',
      'primary_600' => '#2B88D9',
      'primary_700' => '#2577B5',
      'primary_800' => '#1F679A',
      'primary_900' => '#195581',
      'secondary' => '#FFC300',
      'secondary_050' => '#FFF4E6',
      'secondary_100' => '#FFE0B2',
      'secondary_200' => '#FFD180',
      'secondary_300' => '#FFBD4D',
      'secondary_400' => '#FFAA1A',
      'secondary_500' => '#FF9F1C',
      'secondary_600' => '#FF931E',
      'secondary_700' => '#FF881F',
      'secondary_800' => '#FF7C21',
      'secondary_900' => '#FF7122',
      'accent' => '#E74C3C',
      'accent_050' => '#F9EBE7',
      'accent_100' => '#F0D9D0',
      'accent_200' => '#E6B0A5',
      'accent_300' => '#DC8179',
      'accent_400' => '#D3544F',
      'accent_500' => '#E74C3C',
      'accent_600' => '#C0392B',
      'accent_700' => '#A93226',
      'accent_800' => '#922B21',
      'accent_900' => '#7B241C',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['hardware_store'] = [
    'title' => 'Hardware Store',
    'colors' => [
      'primary' => '#2ECC71',
      'primary_050' => '#E5F9ED',
      'primary_100' => '#C3F0D6',
      'primary_200' => '#9DE1BD',
      'primary_300' => '#78D3A4',
      'primary_400' => '#52C68B',
      'primary_500' => '#2ECC71',
      'primary_600' => '#28B765',
      'primary_700' => '#22A859',
      'primary_800' => '#1D9A4E',
      'primary_900' => '#178B43',
      'secondary' => '#3498DB',
      'secondary_050' => '#EAEFF2',
      'secondary_100' => '#C5D9E8',
      'secondary_200' => '#A0CCE5',
      'secondary_300' => '#7FB3D5',
      'secondary_400' => '#5A9AC6',
      'secondary_500' => '#3498DB',
      'secondary_600' => '#2B88D9',
      'secondary_700' => '#2577B5',
      'secondary_800' => '#1F679A',
      'secondary_900' => '#195581',
      'accent' => '#E74C3C',
      'accent_050' => '#F9EBE7',
      'accent_100' => '#F0D9D0',
      'accent_200' => '#E6B0A5',
      'accent_300' => '#DC8179',
      'accent_400' => '#D3544F',
      'accent_500' => '#E74C3C',
      'accent_600' => '#C0392B',
      'accent_700' => '#A93226',
      'accent_800' => '#922B21',
      'accent_900' => '#7B241C',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['law_firm'] = [
    'title' => 'Law Firm',
    'colors' => [
      'primary' => '#34495E',
      'primary_050' => '#EBF2F5',
      'primary_100' => '#D6E1E9',
      'primary_200' => '#AABBC8',
      'primary_300' => '#8198A5',
      'primary_400' => '#577180',
      'primary_500' => '#34495E',
      'primary_600' => '#2B3B4D',
      'primary_700' => '#242F40',
      'primary_800' => '#1C252E',
      'primary_900' => '#141B1F',
      'secondary' => '#3498DB',
      'secondary_050' => '#EAEFF2',
      'secondary_100' => '#C5D9E8',
      'secondary_200' => '#A0CCE5',
      'secondary_300' => '#7FB3D5',
      'secondary_400' => '#5A9AC6',
      'secondary_500' => '#3498DB',
      'secondary_600' => '#2B88D9',
      'secondary_700' => '#2577B5',
      'secondary_800' => '#1F679A',
      'secondary_900' => '#195581',
      'accent' => '#E74C3C',
      'accent_050' => '#F9EBE7',
      'accent_100' => '#F0D9D0',
      'accent_200' => '#E6B0A5',
      'accent_300' => '#DC8179',
      'accent_400' => '#D3544F',
      'accent_500' => '#E74C3C',
      'accent_600' => '#C0392B',
      'accent_700' => '#A93226',
      'accent_800' => '#922B21',
      'accent_900' => '#7B241C',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['toy_store'] = [
    'title' => 'Toy Store',
    'colors' => [
      'primary' => '#FF6B6B',
      'primary_050' => '#FFEBEE',
      'primary_100' => '#FFCDD2',
      'primary_200' => '#EF9A9A',
      'primary_300' => '#E57373',
      'primary_400' => '#EF5350',
      'primary_500' => '#FF6B6B',
      'primary_600' => '#E74C3C',
      'primary_700' => '#D63031',
      'primary_800' => '#C0392B',
      'primary_900' => '#B71C1C',
      'secondary' => '#3498DB',
      'secondary_050' => '#EAEFF2',
      'secondary_100' => '#C5D9E8',
      'secondary_200' => '#A0CCE5',
      'secondary_300' => '#7FB3D5',
      'secondary_400' => '#5A9AC6',
      'secondary_500' => '#3498DB',
      'secondary_600' => '#2B88D9',
      'secondary_700' => '#2577B5',
      'secondary_800' => '#1F679A',
      'secondary_900' => '#195581',
      'accent' => '#F39C12',
      'accent_050' => '#FEF9E7',
      'accent_100' => '#FCF3CF',
      'accent_200' => '#F9E79F',
      'accent_300' => '#F7DC6F',
      'accent_400' => '#F4D03F',
      'accent_500' => '#F39C12',
      'accent_600' => '#D68910',
      'accent_700' => '#B9770E',
      'accent_800' => '#9A7D0A',
      'accent_900' => '#7D6608',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['christmas'] = [
    'title' => 'Christmas',
    'colors' => [
      'primary' => '#D35400',
      'primary_050' => '#FDEBD0',
      'primary_100' => '#FAD7A0',
      'primary_200' => '#F8C471',
      'primary_300' => '#F5B041',
      'primary_400' => '#F39C12',
      'primary_500' => '#D35400',
      'primary_600' => '#BA4A00',
      'primary_700' => '#A04000',
      'primary_800' => '#873600',
      'primary_900' => '#6E2C00',
      'secondary' => '#1ABC9C',
      'secondary_050' => '#E8F8F5',
      'secondary_100' => '#D1F2EB',
      'secondary_200' => '#A3E4D7',
      'secondary_300' => '#76D7C4',
      'secondary_400' => '#48C9B0',
      'secondary_500' => '#1ABC9C',
      'secondary_600' => '#17A589',
      'secondary_700' => '#148F77',
      'secondary_800' => '#117864',
      'secondary_900' => '#0E6251',
      'accent' => '#C0392B',
      'accent_050' => '#F9EBE9',
      'accent_100' => '#F2D7D5',
      'accent_200' => '#E6B0AA',
      'accent_300' => '#D9877D',
      'accent_400' => '#CC6450',
      'accent_500' => '#C0392B',
      'accent_600' => '#AB3324',
      'accent_700' => '#962C1D',
      'accent_800' => '#7F2416',
      'accent_900' => '#6A1D10',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['halloween'] = [
    'title' => 'Halloween',
    'colors' => [
      'primary' => '#FF6B6B',
      'primary_050' => '#FFEBEE',
      'primary_100' => '#FFCDD2',
      'primary_200' => '#EF9A9A',
      'primary_300' => '#E57373',
      'primary_400' => '#EF5350',
      'primary_500' => '#FF6B6B',
      'primary_600' => '#E74C3C',
      'primary_700' => '#D63031',
      'primary_800' => '#C0392B',
      'primary_900' => '#B71C1C',
      'secondary' => '#3498DB',
      'secondary_050' => '#EAEFF2',
      'secondary_100' => '#C5D9E8',
      'secondary_200' => '#A0CCE5',
      'secondary_300' => '#7FB3D5',
      'secondary_400' => '#5A9AC6',
      'secondary_500' => '#3498DB',
      'secondary_600' => '#2B88D9',
      'secondary_700' => '#2577B5',
      'secondary_800' => '#1F679A',
      'secondary_900' => '#195581',
      'accent' => '#F39C12',
      'accent_050' => '#FEF9E7',
      'accent_100' => '#FCF3CF',
      'accent_200' => '#F9E79F',
      'accent_300' => '#F7DC6F',
      'accent_400' => '#F4D03F',
      'accent_500' => '#F39C12',
      'accent_600' => '#D68910',
      'accent_700' => '#B9770E',
      'accent_800' => '#9A7D0A',
      'accent_900' => '#7D6608',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50'
    ]
  ];

  $palettes['dark'] = [
    'title' => 'Dark',
    'colors' => [
      'primary' => '#2C3E50',
      'primary_050' => '#FDFEFE',
      'primary_100' => '#D5DBDB',
      'primary_200' => '#ABB2B2',
      'primary_300' => '#7F8C8D',
      'primary_400' => '#5F6A6A',
      'primary_500' => '#2C3E50',
      'primary_600' => '#283747',
      'primary_700' => '#212F3D',
      'primary_800' => '#1B2631',
      'primary_900' => '#121A21',
      'secondary' => '#8E44AD',
      'secondary_050' => '#F5EEF8',
      'secondary_100' => '#EAD7F4',
      'secondary_200' => '#D4B9E1',
      'secondary_300' => '#C39BD3',
      'secondary_400' => '#AF7AC5',
      'secondary_500' => '#8E44AD',
      'secondary_600' => '#7D3C98',
      'secondary_700' => '#6C3483',
      'secondary_800' => '#5B2C6F',
      'secondary_900' => '#4A235A',
      'accent' => '#E74C3C',
      'accent_050' => '#F9EBE7',
      'accent_100' => '#F0D9D0',
      'accent_200' => '#E6B0A5',
      'accent_300' => '#DC8179',
      'accent_400' => '#D3544F',
      'accent_500' => '#E74C3C',
      'accent_600' => '#C0392B',
      'accent_700' => '#A93226',
      'accent_800' => '#922B21',
      'accent_900' => '#7B241C',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50',
    ]
  ];

  $palettes['dark_v2'] = [
    'title' => 'Dark V2',
    'colors' => [
      'primary' => '#34495E',
      'primary_050' => '#EBF2F5',
      'primary_100' => '#D6E1E9',
      'primary_200' => '#AABBC8',
      'primary_300' => '#8198A5',
      'primary_400' => '#577180',
      'primary_500' => '#34495E',
      'primary_600' => '#2B3B4D',
      'primary_700' => '#242F40',
      'primary_800' => '#1C252E',
      'primary_900' => '#141B1F',
      'secondary' => '#E74C3C',
      'secondary_050' => '#F9EBE7',
      'secondary_100' => '#F0D9D0',
      'secondary_200' => '#E6B0A5',
      'secondary_300' => '#DC8179',
      'secondary_400' => '#D3544F',
      'secondary_500' => '#E74C3C',
      'secondary_600' => '#C0392B',
      'secondary_700' => '#A93226',
      'secondary_800' => '#922B21',
      'secondary_900' => '#7B241C',
      'accent' => '#3498DB',
      'accent_050' => '#EAEFF2',
      'accent_100' => '#C5D9E8',
      'accent_200' => '#A0CCE5',
      'accent_300' => '#7FB3D5',
      'accent_400' => '#5A9AC6',
      'accent_500' => '#3498DB',
      'accent_600' => '#2B88D9',
      'accent_700' => '#2577B5',
      'accent_800' => '#1F679A',
      'accent_900' => '#195581',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50',
    ]
  ];

  $palettes['neon_80s'] = [
    'title' => 'Neon 80s',
    'colors' => [
      'primary' => '#FF00FF',
      'primary_050' => '#FFD9FF',
      'primary_100' => '#FFA3FF',
      'primary_200' => '#FF6DFF',
      'primary_300' => '#FF37FF',
      'primary_400' => '#FF00FF',
      'primary_500' => '#FF00CC',
      'primary_600' => '#CC0099',
      'primary_700' => '#990066',
      'primary_800' => '#660033',
      'primary_900' => '#330000',
      'secondary' => '#00FFFF',
      'secondary_050' => '#E6FFFF',
      'secondary_100' => '#B3FFFF',
      'secondary_200' => '#80FFFF',
      'secondary_300' => '#4DFFFF',
      'secondary_400' => '#00FFFF',
      'secondary_500' => '#00CCCC',
      'secondary_600' => '#009999',
      'secondary_700' => '#006666',
      'secondary_800' => '#003333',
      'secondary_900' => '#000000',
      'accent' => '#FFFF00',
      'accent_050' => '#FFFFE0',
      'accent_100' => '#FFFFB3',
      'accent_200' => '#FFFF66',
      'accent_300' => '#FFFF00',
      'accent_400' => '#CCCC00',
      'accent_500' => '#999900',
      'accent_600' => '#666600',
      'accent_700' => '#333300',
      'accent_800' => '#000000',
      'accent_900' => '#000000',
      'success' => '#00FF00',
      'info' => '#00FFFF',
      'danger' => '#FF0000',
      'warning' => '#FFD700',
      'light' => '#FFFFFF',
      'dark' => '#000000',
    ]
  ];

  $palettes['light'] = [
    'title' => 'Light',
    'colors' => [
      'primary' => '#3498DB',
      'primary_050' => '#EAEFF2',
      'primary_100' => '#C5D9E8',
      'primary_200' => '#A0CCE5',
      'primary_300' => '#7FB3D5',
      'primary_400' => '#5A9AC6',
      'primary_500' => '#3498DB',
      'primary_600' => '#2B88D9',
      'primary_700' => '#2577B5',
      'primary_800' => '#1F679A',
      'primary_900' => '#195581',
      'secondary' => '#27AE60',
      'secondary_050' => '#E8F8F5',
      'secondary_100' => '#D1F2EB',
      'secondary_200' => '#A3E4D7',
      'secondary_300' => '#76D7C4',
      'secondary_400' => '#48C9B0',
      'secondary_500' => '#27AE60',
      'secondary_600' => '#219D55',
      'secondary_700' => '#1F8E4B',
      'secondary_800' => '#1A7E44',
      'secondary_900' => '#166B39',
      'accent' => '#F39C12',
      'accent_050' => '#FEF9E7',
      'accent_100' => '#FCF3CF',
      'accent_200' => '#F9E79F',
      'accent_300' => '#F7DC6F',
      'accent_400' => '#F4D03F',
      'accent_500' => '#F39C12',
      'accent_600' => '#D68910',
      'accent_700' => '#B9770E',
      'accent_800' => '#9A7D0A',
      'accent_900' => '#7D6608',
      'success' => '#27AE60',
      'info' => '#3498DB',
      'danger' => '#E74C3C',
      'warning' => '#F39C12',
      'light' => '#FDFEFE',
      'dark' => '#2C3E50',
    ]
  ];

  foreach ($palettes as $palette) {
    $palette['colors'] = array_merge($palette['colors'], $colors);
    $palette['colors'] = array_merge($palette['colors'], $grays);
  }

  return $palettes;
}